#
# spec file for package klee-uclibc
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define llvm_version 14

Name:           klee-uclibc
Summary:        Libc library for Klee
License:        LGPL-2.1-or-later
Group:          Development/Languages/Other
Version:        1.3
Release:        bp156.5.3
URL:            https://github.com/klee/klee-uclibc
Source0:        https://github.com/klee/klee-uclibc/archive/klee_uclibc_v%{version}.tar.gz
Source1:        %{name}-rpmlintrc
Source2:        uClibc-locale-030818.tgz
Patch0:         extra-locale-Makefile-don-t-always-require-curl-wget.patch
Patch1:         proper-compiler-flags-check.patch
Patch2:         0001-strtod-fix-__strtofpmax.patch
BuildRequires:  clang%{llvm_version}
BuildRequires:  llvm%{llvm_version}-devel
BuildRequires:  make
BuildRequires:  ncurses-devel
BuildRequires:  python3-base
BuildRequires:  xz
ExclusiveArch:  x86_64

%description
This is a port of uClibc to LLVM to serve Klee. Hence, this package
provides a "static" library, but it is not composed of ELF objects, but is
LLVM bytecode packed by `ar`. Klee uses this to emulate the POSIX runtime
development symbolically.

%package devel-static
Summary:        Libc library for Klee
Group:          Development/Languages/Other
Provides:       %{name}-devel-static(llvm%{llvm_version})

%description devel-static
This is a port of uClibc to LLVM to serve Klee. Hence, this package
provides a "static" library, but it is not composed of ELF objects, but is
LLVM bytecode packed by `ar`. Klee uses this to emulate the POSIX runtime
development symbolically.

%prep
%autosetup -p1 -n %{name}-klee_uclibc_v%{version}
cp %{SOURCE2} extra/locale/
sed -i 's@UCLIBC_DOWNLOAD_PREGENERATED_LOCALE_DATA=y@@' klee-premade-configs/x86_64/config

%build
./configure \
	--make-llvm-lib \
	--enable-release
make %{?_smp_mflags} V=1 lib/libc.a

%install
install -d %{buildroot}%{_libdir}/%{name}/lib/
install -m 0644 lib/libc.a %{buildroot}%{_libdir}/%{name}/lib/

%files devel-static
%doc README README.md TODO
%license COPYING.LIB
%dir %{_libdir}/%{name}/
%dir %{_libdir}/%{name}/lib/
%{_libdir}/%{name}/lib/libc.a

%changelog
* Thu Jun 15 2023 jslaby@suse.cz
- require python3-base, not python-base as we need py3
- update rpmlintrc filter to match the current output
* Tue Nov 22 2022 Jiri Slaby <jslaby@suse.cz>
- add 0001-strtod-fix-__strtofpmax.patch (build fix w/ LLVM 15)
* Tue Sep  6 2022 Jiri Slaby <jslaby@suse.cz>
- Switch to LLVM 14.
* Tue May 10 2022 Jiri Slaby <jslaby@suse.cz>
- update to 1.3
  * configure: remove old code, make llvm-config lookup more flexible,
    set to Python3, remove trailing whitespace
  * switch to https; fallback to curl when wget not available
  * Correcting use of 'lookForNew'
  * Add a message when the bitcode compiler is specified via CC
- add extra-locale-Makefile-don-t-always-require-curl-wget.patch to
  fix build
* Tue Oct 19 2021 Jiri Slaby <jslaby@suse.cz>
- Switch to LLVM 13.
* Thu May 20 2021 Jiri Slaby <jslaby@suse.cz>
- Switch to LLVM 12.
* Sun Dec 13 2020 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Switch to regular version 1.2. That's a slight downgrade, as we
  lose the last two commits, but they aren't relevant here.
- Switch to LLVM 11.
* Thu Sep 24 2020 jslaby@suse.com
- Update to version 1.0.0+git.20200711:
  * Correcting use of 'lookForNew' and some rudimentary code tidying in 'configure'
- disable x86_32 as it is unsupported -- there are bugs in klee.
* Fri Apr 24 2020 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Switch to LLVM 10.
* Mon Nov  4 2019 Jiri Slaby <jslaby@suse.com>
- switch to llvm 9
* Fri Oct  4 2019 jslaby@suse.com
- Update to version 1.0.0+git.20190816:
  * Add a message when the bitcode compiler is specified via CC,
    to help diagnose cases in which CC does not point to a valid
    bitcode compiler.
  * Check if pointer size reflects architecture
  * Use newer gcc to compile KLEE
  * Fix compilation when __STDIO_HAS_OPENLIST is undefined
* Wed Aug 21 2019 Aaron Puchert <aaronpuchert@alice-dsl.net>
- The build requires ncurses-devel, and this will soon no longer be
  transitively included via llvm-devel.
* Mon Jul  1 2019 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Switch to LLVM 8.
* Mon Oct 29 2018 jslaby@suse.com
- Update to version 1.0.0+git.20180926:
  * Replaced README.klee with README.md, which now also includes a TravisCI build status.
  * Revert lit to 0.6.0 version, as 0.7.0 misbehaves
  * Backport uclibc PR 4964 to fix pointer error in newlocale
  * Enable locale support for uclibc
  * - Fix strtol*() with xlocale (on e.g. x86_64) (closes #2544)
  * Disable default tcmalloc build for uclibc testing
- switch to LLVM 7
* Sun Sep  2 2018 jslaby@suse.com
- Update to version 1.0.0+git.20171011:
  * Updated Travis-CI to compile KLEE with CMake only
  * Sort list of ar input files
  * Removed support for LLVM 2.9
  * configure: read kernel header location from environment variable
  * features: support glibc 2.25
- remove 0001-features-support-glibc-2.25.patch (in upstream)
* Sat Jun 16 2018 jslaby@suse.com
- switch to LLVM 6
* Wed Dec 27 2017 dimstar@opensuse.org
- Revert llvm_version back to 4: klee is not ready yet to build
  using llvm5.
* Tue Dec 19 2017 dimstar@opensuse.org
- Change llvm_Version to 5, following the switch of LLVM to version
  5 in Tumbleweed.
* Tue Jun 27 2017 jslaby@suse.com
- require only base of python
* Thu Jun  8 2017 jslaby@suse.com
- switch to LLVM 4
- BuildRequire: python as it is needed for configure
- add proper-compiler-flags-check.patch to kill the message flood
* Fri Mar 31 2017 jengelh@inai.de
- Resolve some orthographic errors.
* Thu Mar 30 2017 jslaby@suse.com
- Change license to LGPL-2.1+, the same as is in uClibc in Factory
* Fri Mar 24 2017 jslaby@suse.com
- Update to version 1.0.0+git.20170324:
  * Enable program_invocation_name feature
  * Enable C99 math by default
  * Hack the `libm_*()` macros to be no-ops like we do with the `libc_*()` macros. See 7217b2a28e792c1118244ad897346c6c2b6cba41 for the reasoning here.
  * Added Travis-CI integration. The script is heavily based on the one used in KLEE.
* Thu Mar 23 2017 jengelh@inai.de
- Avoid unnecessary %%__-type macro indirections.
* Mon Mar 20 2017 jslaby@suse.com
- kill the main package
* Fri Mar 17 2017 jslaby@suse.com
- split into -devel-static
* Sat Mar 11 2017 jslaby@suse.com
- add glibc 2.25 support: 0001-features-support-glibc-2.25.patch
* Thu Mar  2 2017 jslaby@suse.com
- Update to version 1.0.0+20131211:
  * Added a hack originally added by DWD that prevented compiliation errors.
  * Fixed build on i686 on Linux 3.11.6.
  * Exit cleanly if llvm-config cannot be found.
  * Fixed building host code (make menuconfig code). llvm-gcc out of the box might not be able to link correctly so in this case we use 'cc' instead of llvm-gcc for the host code.
  * configure script checks for ncurses (needed for make menuconfig)
  * Exit gracefully if argparse can't be imported (user probably has python version < 2.7).
  * Fix small bug in b5c6cea400e58ac8848db8aa2fefc695b0357b4e where compiler temporary file would not be removed when checking for ncurses.
  * Search for Kernel headers
  * Add more log output when patching .config file for KERNEL_HEADERS
  * Use os.path.join instead of explicit string concatentation.
* Thu Mar  2 2017 jslaby@suse.com
- initial package
